package X6FRs_4.JZJr_16;

import android.graphics.Matrix;
import android.graphics.RectF;
/* compiled from: MatrixUtils.java */
/* loaded from: classes.dex */
public class XnFJ5_9 {
    public static final Matrix KQgRr5e_0 = new KQgRr5e_0();

    /* compiled from: MatrixUtils.java */
    /* loaded from: classes.dex */
    public static class KQgRr5e_0 extends Matrix {
        public void KQgRr5e_0() {
            throw new IllegalStateException("Matrix can not be modified");
        }

        @Override // android.graphics.Matrix
        public boolean postConcat(Matrix matrix) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean postRotate(float f, float f2, float f3) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean postScale(float f, float f2, float f3, float f4) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean postSkew(float f, float f2, float f3, float f4) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean postTranslate(float f, float f2) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean preConcat(Matrix matrix) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean preRotate(float f, float f2, float f3) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean preScale(float f, float f2, float f3, float f4) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean preSkew(float f, float f2, float f3, float f4) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean preTranslate(float f, float f2) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void reset() {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void set(Matrix matrix) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean setConcat(Matrix matrix, Matrix matrix2) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean setPolyToPoly(float[] fArr, int i, float[] fArr2, int i2, int i3) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean setRectToRect(RectF rectF, RectF rectF2, Matrix.ScaleToFit scaleToFit) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void setRotate(float f, float f2, float f3) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void setScale(float f, float f2, float f3, float f4) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void setSinCos(float f, float f2, float f3, float f4) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void setSkew(float f, float f2, float f3, float f4) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void setTranslate(float f, float f2) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void setValues(float[] fArr) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean postRotate(float f) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean postScale(float f, float f2) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean postSkew(float f, float f2) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean preRotate(float f) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean preScale(float f, float f2) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public boolean preSkew(float f, float f2) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void setRotate(float f) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void setScale(float f, float f2) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void setSinCos(float f, float f2) {
            KQgRr5e_0();
            throw null;
        }

        @Override // android.graphics.Matrix
        public void setSkew(float f, float f2) {
            KQgRr5e_0();
            throw null;
        }
    }
}
